<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

/**
 * Auto-generated Migration: Please modify to your needs!
 */
final class Version20260507074116 extends AbstractMigration
{
    public function getDescription(): string
    {
        return '';
    }

    public function up(Schema $schema): void
    {
        // this up() migration is auto-generated, please modify it to your needs
        $this->addSql('CREATE SEQUENCE event_event_image_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE SEQUENCE news_news_image_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE SEQUENCE product_product_files_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE SEQUENCE product_product_image_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE SEQUENCE product_variant_image_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE SEQUENCE product_variant_option_image_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE TABLE award_award (id UUID NOT NULL, image_id UUID DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_857D6ED13DA5256D ON award_award (image_id)');
        $this->addSql('COMMENT ON COLUMN award_award.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN award_award.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN award_award.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN award_award.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE award_award_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, title VARCHAR(255) NOT NULL, description TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_1A78042C2AC5D3 ON award_award_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX award_award_translation_unique_translation ON award_award_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN award_award_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN award_award_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE cart_cart (id UUID NOT NULL, delivery_method_id UUID DEFAULT NULL, invoice_address_id UUID DEFAULT NULL, delivery_address_id UUID DEFAULT NULL, user_id UUID DEFAULT NULL, invoice_id UUID DEFAULT NULL, token TEXT DEFAULT NULL, tax NUMERIC(5, 4) DEFAULT NULL, group_code VARCHAR(255) DEFAULT NULL, view_ht BOOLEAN DEFAULT NULL, comment TEXT DEFAULT NULL, delivery BOOLEAN DEFAULT false NOT NULL, cgv BOOLEAN DEFAULT false NOT NULL, locale VARCHAR(10) DEFAULT \'fr\' NOT NULL, code_carrier VARCHAR(255) DEFAULT NULL, url_de_suivi_carrier VARCHAR(255) DEFAULT NULL, ip_client VARCHAR(255) DEFAULT NULL, document_type VARCHAR(32) DEFAULT \'order\' NOT NULL, expires_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, cart_pricing JSONB DEFAULT NULL, cart_shipping JSONB DEFAULT NULL, cart_promos JSONB DEFAULT NULL, promo_code_input VARCHAR(255) DEFAULT NULL, promo_code_status VARCHAR(255) DEFAULT NULL, promo_code_message_key VARCHAR(255) DEFAULT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_E446888E5DED75F5 ON cart_cart (delivery_method_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_E446888EC6BDFEB ON cart_cart (invoice_address_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_E446888EEBF23851 ON cart_cart (delivery_address_id)');
        $this->addSql('CREATE INDEX IDX_E446888EA76ED395 ON cart_cart (user_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_E446888E2989F1FD ON cart_cart (invoice_id)');
        $this->addSql('COMMENT ON COLUMN cart_cart.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.delivery_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.invoice_address_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.delivery_address_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.user_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.invoice_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.expires_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.cart_pricing IS \'(DC2Type:json_document)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.cart_shipping IS \'(DC2Type:json_document)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.cart_promos IS \'(DC2Type:json_document)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE cart_cart_checkout (id UUID NOT NULL, payment_method_id UUID DEFAULT NULL, cart_cart_id UUID DEFAULT NULL, payed_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, ordered_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, payed_token VARCHAR(255) DEFAULT NULL, response JSON DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_5BF344B5AA1164F ON cart_cart_checkout (payment_method_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_5BF344BE10F05B8 ON cart_cart_checkout (cart_cart_id)');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.payment_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.cart_cart_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.ordered_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_checkout.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE cart_cart_item (id UUID NOT NULL, cart_cart_id UUID DEFAULT NULL, product_variant_id UUID DEFAULT NULL, quantity INT NOT NULL, selected_option_name TEXT DEFAULT NULL, selected_option_price INT DEFAULT NULL, selected_option_flat_fee BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_2A0002B8E10F05B8 ON cart_cart_item (cart_cart_id)');
        $this->addSql('CREATE INDEX IDX_2A0002B8A80EF684 ON cart_cart_item (product_variant_id)');
        $this->addSql('COMMENT ON COLUMN cart_cart_item.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_item.cart_cart_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_item.product_variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_item.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_cart_item.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE cart_delivery_address (id UUID NOT NULL, email TEXT DEFAULT NULL, phone VARCHAR(12) DEFAULT NULL, lastname VARCHAR(255) DEFAULT NULL, firstname VARCHAR(255) DEFAULT NULL, company VARCHAR(255) DEFAULT NULL, siret VARCHAR(14) DEFAULT NULL, vat_id VARCHAR(16) DEFAULT NULL, street VARCHAR(255) DEFAULT NULL, postal VARCHAR(8) DEFAULT NULL, city VARCHAR(255) DEFAULT NULL, country VARCHAR(2) DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN cart_delivery_address.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE cart_invoice (id UUID NOT NULL, number_debit INT DEFAULT NULL, number_credit INT DEFAULT NULL, year INT DEFAULT NULL, credit BOOLEAN NOT NULL, credit_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, type VARCHAR(255) NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN cart_invoice.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_invoice.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_invoice.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE cart_invoice_address (id UUID NOT NULL, email TEXT DEFAULT NULL, different_address BOOLEAN DEFAULT false NOT NULL, phone VARCHAR(12) DEFAULT NULL, lastname VARCHAR(255) DEFAULT NULL, firstname VARCHAR(255) DEFAULT NULL, company VARCHAR(255) DEFAULT NULL, siret VARCHAR(14) DEFAULT NULL, vat_id VARCHAR(16) DEFAULT NULL, street VARCHAR(255) DEFAULT NULL, postal VARCHAR(8) DEFAULT NULL, city VARCHAR(255) DEFAULT NULL, country VARCHAR(2) DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN cart_invoice_address.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE cart_payment_method (id UUID NOT NULL, image_id UUID DEFAULT NULL, method VARCHAR(255) DEFAULT NULL, payment_online BOOLEAN NOT NULL, position INT DEFAULT 0 NOT NULL, disabled BOOLEAN DEFAULT false NOT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_D15FF5FF3DA5256D ON cart_payment_method (image_id)');
        $this->addSql('COMMENT ON COLUMN cart_payment_method.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_payment_method.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_payment_method.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_payment_method.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_payment_method.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE cart_payment_method_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, configuration JSON NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_6F3AC5652C2AC5D3 ON cart_payment_method_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX cart_payment_method_translation_unique_translation ON cart_payment_method_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN cart_payment_method_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_payment_method_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE cart_promo (id UUID NOT NULL, offered_variant_id UUID DEFAULT NULL, assigned_user_id UUID DEFAULT NULL, title VARCHAR(255) DEFAULT NULL, percent NUMERIC(5, 2) DEFAULT NULL, amount_ttc INT DEFAULT NULL, percent_shipping_cost NUMERIC(5, 2) DEFAULT NULL, begin_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, end_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, count INT DEFAULT 0 NOT NULL, auto BOOLEAN DEFAULT false NOT NULL, multiple_by_quantity BOOLEAN DEFAULT false NOT NULL, include_shipping_fees BOOLEAN DEFAULT false NOT NULL, cumulative BOOLEAN DEFAULT false NOT NULL, max_count INT DEFAULT NULL, max_count_by_customer INT DEFAULT NULL, min_equivalency INT DEFAULT NULL, max_equivalency INT DEFAULT NULL, min_subtotal_ttc INT DEFAULT NULL, notification_email VARCHAR(255) DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_EFF9F7F3B93BFD91 ON cart_promo (offered_variant_id)');
        $this->addSql('CREATE INDEX IDX_EFF9F7F3ADF66B1A ON cart_promo (assigned_user_id)');
        $this->addSql('COMMENT ON COLUMN cart_promo.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_promo.offered_variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_promo.assigned_user_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_promo.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN cart_promo.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE promo_product_price_group (promo_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(promo_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_B306621DD0C07AFF ON promo_product_price_group (promo_id)');
        $this->addSql('CREATE INDEX IDX_B306621DCF8B9C7C ON promo_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN promo_product_price_group.promo_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN promo_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE promo_shipping_zone (promo_id UUID NOT NULL, shipping_zone_id UUID NOT NULL, PRIMARY KEY(promo_id, shipping_zone_id))');
        $this->addSql('CREATE INDEX IDX_B21CD505D0C07AFF ON promo_shipping_zone (promo_id)');
        $this->addSql('CREATE INDEX IDX_B21CD5057964396F ON promo_shipping_zone (shipping_zone_id)');
        $this->addSql('COMMENT ON COLUMN promo_shipping_zone.promo_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN promo_shipping_zone.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE promo_product (promo_id UUID NOT NULL, product_id UUID NOT NULL, PRIMARY KEY(promo_id, product_id))');
        $this->addSql('CREATE INDEX IDX_DB3EBC9FD0C07AFF ON promo_product (promo_id)');
        $this->addSql('CREATE INDEX IDX_DB3EBC9F4584665A ON promo_product (product_id)');
        $this->addSql('COMMENT ON COLUMN promo_product.promo_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN promo_product.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE cart_promo_incompatible_auto (promo_source_id UUID NOT NULL, promo_target_id UUID NOT NULL, PRIMARY KEY(promo_source_id, promo_target_id))');
        $this->addSql('CREATE INDEX IDX_7ADFD619BDF67BDA ON cart_promo_incompatible_auto (promo_source_id)');
        $this->addSql('CREATE INDEX IDX_7ADFD6193D446CDD ON cart_promo_incompatible_auto (promo_target_id)');
        $this->addSql('COMMENT ON COLUMN cart_promo_incompatible_auto.promo_source_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN cart_promo_incompatible_auto.promo_target_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE contact_contact (id UUID NOT NULL, file_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, company TEXT DEFAULT NULL, firstname TEXT DEFAULT NULL, lastname TEXT DEFAULT NULL, address TEXT NOT NULL, postal TEXT NOT NULL, city TEXT NOT NULL, phone1 TEXT NOT NULL, phone2 TEXT DEFAULT NULL, phone3 TEXT DEFAULT NULL, email_from TEXT NOT NULL, email_to_message TEXT NOT NULL, email_to_shop TEXT NOT NULL, facebook TEXT DEFAULT NULL, instagram TEXT DEFAULT NULL, twitter TEXT DEFAULT NULL, recaptcha BOOLEAN DEFAULT false NOT NULL, recaptcha_key_public TEXT DEFAULT NULL, recaptcha_key_private TEXT DEFAULT NULL, editor_company TEXT DEFAULT NULL, editor_rcs TEXT DEFAULT NULL, editor_tva TEXT DEFAULT NULL, editor_address TEXT DEFAULT NULL, editor_postal TEXT DEFAULT NULL, editor_city TEXT DEFAULT NULL, cgv TEXT DEFAULT NULL, committee_champagne_siret TEXT DEFAULT NULL, committee_champagne_identifiant TEXT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_D64DC7B993CB796C ON contact_contact (file_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_D64DC7B93DA5256D ON contact_contact (image_id)');
        $this->addSql('COMMENT ON COLUMN contact_contact.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_contact.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_contact.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_contact.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN contact_contact.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE contact_label (id UUID NOT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_238D40E73DA5256D ON contact_label (image_id)');
        $this->addSql('COMMENT ON COLUMN contact_label.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_label.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_label.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN contact_label.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE contact_label_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, text TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_A81638CE2C2AC5D3 ON contact_label_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX contact_label_translation_unique_translation ON contact_label_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN contact_label_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN contact_label_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE depot_category (id UUID NOT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, color VARCHAR(7) DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_81579E5F3DA5256D ON depot_category (image_id)');
        $this->addSql('COMMENT ON COLUMN depot_category.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN depot_category.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE depot_category_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, slug VARCHAR(255) NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_5BC6183989D9B62 ON depot_category_translation (slug)');
        $this->addSql('CREATE INDEX IDX_5BC61832C2AC5D3 ON depot_category_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX depot_category_translation_unique_translation ON depot_category_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN depot_category_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN depot_category_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE depot_depot (id UUID NOT NULL, depot_category_id UUID DEFAULT NULL, phone TEXT DEFAULT NULL, website TEXT DEFAULT NULL, email TEXT DEFAULT NULL, position INT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, address TEXT DEFAULT NULL, postal TEXT NOT NULL, city TEXT NOT NULL, country TEXT NOT NULL, lat TEXT DEFAULT NULL, lng TEXT DEFAULT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_2165D81B1B6CCFFF ON depot_depot (depot_category_id)');
        $this->addSql('COMMENT ON COLUMN depot_depot.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN depot_depot.depot_category_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN depot_depot.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN depot_depot.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN depot_depot.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE depot_depot_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT DEFAULT NULL, description TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_8086EE492C2AC5D3 ON depot_depot_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX depot_depot_translation_unique_translation ON depot_depot_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN depot_depot_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN depot_depot_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE event_event (id UUID NOT NULL, file_id UUID DEFAULT NULL, begin_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, end_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, url TEXT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, address TEXT DEFAULT NULL, postal TEXT NOT NULL, city TEXT NOT NULL, country TEXT NOT NULL, lat TEXT DEFAULT NULL, lng TEXT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_7AB5BB8B93CB796C ON event_event (file_id)');
        $this->addSql('COMMENT ON COLUMN event_event.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN event_event.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN event_event.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN event_event.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE event_event_image (id INT NOT NULL, event_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_2FAF66F371F7E88B ON event_event_image (event_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_2FAF66F33DA5256D ON event_event_image (image_id)');
        $this->addSql('COMMENT ON COLUMN event_event_image.event_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN event_event_image.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN event_event_image.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN event_event_image.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE event_event_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, slug VARCHAR(255) NOT NULL, description TEXT DEFAULT NULL, file_title TEXT DEFAULT NULL, url_title TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_8A79CC8E989D9B62 ON event_event_translation (slug)');
        $this->addSql('CREATE INDEX IDX_8A79CC8E2C2AC5D3 ON event_event_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX event_event_translation_unique_translation ON event_event_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN event_event_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN event_event_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE library_library (id UUID NOT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_DB41208C3DA5256D ON library_library (image_id)');
        $this->addSql('COMMENT ON COLUMN library_library.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN library_library.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN library_library.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN library_library.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE library_library_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, title TEXT DEFAULT NULL, legend TEXT DEFAULT NULL, slug VARCHAR(255) NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_EEAFE95D989D9B62 ON library_library_translation (slug)');
        $this->addSql('CREATE INDEX IDX_EEAFE95D2C2AC5D3 ON library_library_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX library_library_translation_unique_translation ON library_library_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN library_library_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN library_library_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE locale_locale (id UUID NOT NULL, name TEXT NOT NULL, locale TEXT NOT NULL, position INT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN locale_locale.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN locale_locale.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN locale_locale.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE media_media (id UUID NOT NULL, path VARCHAR(255) DEFAULT NULL, title VARCHAR(255) DEFAULT NULL, published BOOLEAN NOT NULL, mime_type VARCHAR(255) DEFAULT NULL, size INT DEFAULT NULL, original_name VARCHAR(255) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, type VARCHAR(255) NOT NULL, width INT DEFAULT NULL, height INT DEFAULT NULL, platform VARCHAR(255) DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN media_media.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN media_media.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN media_media.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE news_category (id UUID NOT NULL, position INT DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN news_category.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE news_category_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, slug VARCHAR(255) NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_C8B8CAF9989D9B62 ON news_category_translation (slug)');
        $this->addSql('CREATE INDEX IDX_C8B8CAF92C2AC5D3 ON news_category_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX news_category_translation_unique_translation ON news_category_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN news_category_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_category_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE news_news (id UUID NOT NULL, news_category_id UUID DEFAULT NULL, file_id UUID DEFAULT NULL, video_id UUID DEFAULT NULL, un_published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, event_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, address VARCHAR(255) DEFAULT NULL, postal VARCHAR(255) DEFAULT NULL, city VARCHAR(255) DEFAULT NULL, country VARCHAR(255) DEFAULT NULL, author VARCHAR(255) DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_C80E6FDB3B732BAD ON news_news (news_category_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_C80E6FDB93CB796C ON news_news (file_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_C80E6FDB29C1004E ON news_news (video_id)');
        $this->addSql('COMMENT ON COLUMN news_news.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news.news_category_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news.video_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN news_news.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE news_news_image (id INT NOT NULL, news_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_53FD5478B5A459A0 ON news_news_image (news_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_53FD54783DA5256D ON news_news_image (image_id)');
        $this->addSql('COMMENT ON COLUMN news_news_image.news_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news_image.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news_image.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN news_news_image.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE news_news_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, title TEXT NOT NULL, title2 TEXT DEFAULT NULL, text TEXT NOT NULL, slug VARCHAR(255) NOT NULL, more_info TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_1900956E989D9B62 ON news_news_translation (slug)');
        $this->addSql('CREATE INDEX IDX_1900956E2C2AC5D3 ON news_news_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX news_news_translation_unique_translation ON news_news_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN news_news_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN news_news_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE payment_payment (id UUID NOT NULL, payment_method_id UUID DEFAULT NULL, lastname TEXT NOT NULL, firstname TEXT NOT NULL, street TEXT NOT NULL, postal_code TEXT NOT NULL, city TEXT NOT NULL, email TEXT NOT NULL, phone TEXT NOT NULL, reference TEXT NOT NULL, slug VARCHAR(255) NOT NULL, amount INT NOT NULL, payed_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, response JSON DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_74618AE75AA1164F ON payment_payment (payment_method_id)');
        $this->addSql('COMMENT ON COLUMN payment_payment.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN payment_payment.payment_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN payment_payment.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN payment_payment.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE popup_popup (id UUID NOT NULL, image_id UUID DEFAULT NULL, video_id UUID DEFAULT NULL, un_published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, popup BOOLEAN DEFAULT true NOT NULL, show_title_in_banner BOOLEAN DEFAULT true NOT NULL, url TEXT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_7CC1198F3DA5256D ON popup_popup (image_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_7CC1198F29C1004E ON popup_popup (video_id)');
        $this->addSql('COMMENT ON COLUMN popup_popup.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN popup_popup.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN popup_popup.video_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN popup_popup.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN popup_popup.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE popup_popup_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, title VARCHAR(255) NOT NULL, subtitle TEXT DEFAULT NULL, url_title TEXT DEFAULT NULL, text TEXT NOT NULL, slug VARCHAR(255) NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_ACD6A810989D9B62 ON popup_popup_translation (slug)');
        $this->addSql('CREATE INDEX IDX_ACD6A8102C2AC5D3 ON popup_popup_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX popup_popup_translation_unique_translation ON popup_popup_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN popup_popup_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN popup_popup_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_category (id UUID NOT NULL, position INT NOT NULL, page_cuvee BOOLEAN DEFAULT true NOT NULL, page_shop BOOLEAN DEFAULT true NOT NULL, display_even_without_group_match BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN product_category.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_category.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_category.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_category_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, description TEXT DEFAULT NULL, slug VARCHAR(255) NOT NULL, no_group_match_message TEXT DEFAULT NULL, shop_category_message TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_1DAAB487989D9B62 ON product_category_translation (slug)');
        $this->addSql('CREATE INDEX IDX_1DAAB4872C2AC5D3 ON product_category_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX product_category_translation_unique_translation ON product_category_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN product_category_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_category_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_degressive (id UUID NOT NULL, qty_of INT NOT NULL, qty_at INT NOT NULL, package_price_ttc INT DEFAULT NULL, bottle_price_ttc INT DEFAULT NULL, package_percent NUMERIC(5, 3) DEFAULT NULL, qty_of_bottle_offered INT DEFAULT NULL, equivalency BOOLEAN NOT NULL, all_quantity BOOLEAN NOT NULL, most_order_bottle_in_cart BOOLEAN DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN product_degressive.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_degressive.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_degressive.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_degressive_product_type (product_degressive_id UUID NOT NULL, product_type_id UUID NOT NULL, PRIMARY KEY(product_degressive_id, product_type_id))');
        $this->addSql('CREATE INDEX IDX_E75F62BF54BEF7E ON product_degressive_product_type (product_degressive_id)');
        $this->addSql('CREATE INDEX IDX_E75F62BF14959723 ON product_degressive_product_type (product_type_id)');
        $this->addSql('COMMENT ON COLUMN product_degressive_product_type.product_degressive_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_degressive_product_type.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_degressive_product_price_group (product_degressive_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(product_degressive_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_FE07709D54BEF7E ON product_degressive_product_price_group (product_degressive_id)');
        $this->addSql('CREATE INDEX IDX_FE07709DCF8B9C7C ON product_degressive_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN product_degressive_product_price_group.product_degressive_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_degressive_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_degressive_product (product_degressive_id UUID NOT NULL, product_id UUID NOT NULL, PRIMARY KEY(product_degressive_id, product_id))');
        $this->addSql('CREATE INDEX IDX_CC09F11054BEF7E ON product_degressive_product (product_degressive_id)');
        $this->addSql('CREATE INDEX IDX_CC09F1104584665A ON product_degressive_product (product_id)');
        $this->addSql('COMMENT ON COLUMN product_degressive_product.product_degressive_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_degressive_product.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_option (id UUID NOT NULL, product_type_id UUID DEFAULT NULL, multiple INT NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_38FA411414959723 ON product_option (product_type_id)');
        $this->addSql('COMMENT ON COLUMN product_option.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_option.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_option_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, text TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_608B99A72C2AC5D3 ON product_option_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX product_option_translation_unique_translation ON product_option_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN product_option_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_option_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_price (id UUID NOT NULL, group_id UUID DEFAULT NULL, variant_id UUID DEFAULT NULL, price INT NOT NULL, price_discount INT DEFAULT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_6B945985FE54D947 ON product_price (group_id)');
        $this->addSql('CREATE INDEX IDX_6B9459853B69A9AF ON product_price (variant_id)');
        $this->addSql('COMMENT ON COLUMN product_price.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price.group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price.variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_price_code (id UUID NOT NULL, group_id UUID DEFAULT NULL, code VARCHAR(255) NOT NULL, disabled BOOLEAN DEFAULT false NOT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_99209D09FE54D947 ON product_price_code (group_id)');
        $this->addSql('COMMENT ON COLUMN product_price_code.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price_code.group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price_code.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price_code.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price_code.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_price_group (id UUID NOT NULL, name VARCHAR(255) NOT NULL, by_default BOOLEAN NOT NULL, view_ht BOOLEAN NOT NULL, free_shipping BOOLEAN NOT NULL, position INT DEFAULT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN product_price_group.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_price_group.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price_group.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_price_group.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_product (id UUID NOT NULL, product_category_id UUID DEFAULT NULL, second_image_id UUID DEFAULT NULL, background_image_id UUID DEFAULT NULL, file_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, cuvee BOOLEAN NOT NULL, shop BOOLEAN NOT NULL, favorite BOOLEAN NOT NULL, position INT NOT NULL, position_shop INT DEFAULT NULL, new BOOLEAN NOT NULL, sold_out BOOLEAN NOT NULL, ribbon_custom_color TEXT DEFAULT NULL, enable_color BOOLEAN NOT NULL, enable_color_quality BOOLEAN NOT NULL, color TEXT DEFAULT NULL, color_gradient1 TEXT DEFAULT NULL, color_gradient2 TEXT DEFAULT NULL, order_in_favorites INT DEFAULT NULL, reference_token TEXT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_2931F1DBE6903FD ON product_product (product_category_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_2931F1DEB17A08 ON product_product (second_image_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_2931F1DE6DA28AA ON product_product (background_image_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_2931F1D93CB796C ON product_product (file_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_2931F1D3DA5256D ON product_product (image_id)');
        $this->addSql('COMMENT ON COLUMN product_product.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.product_category_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.second_image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.background_image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_product.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_product.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_award (product_id UUID NOT NULL, award_id UUID NOT NULL, PRIMARY KEY(product_id, award_id))');
        $this->addSql('CREATE INDEX IDX_2B0755BB4584665A ON product_award (product_id)');
        $this->addSql('CREATE INDEX IDX_2B0755BB3D5282CF ON product_award (award_id)');
        $this->addSql('COMMENT ON COLUMN product_award.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_award.award_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_product_price_group (product_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(product_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_B36739284584665A ON product_product_price_group (product_id)');
        $this->addSql('CREATE INDEX IDX_B3673928CF8B9C7C ON product_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN product_product_price_group.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_product_files (id INT NOT NULL, product_id UUID DEFAULT NULL, file_id UUID DEFAULT NULL, locale VARCHAR(255) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_7D8427F74584665A ON product_product_files (product_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_7D8427F793CB796C ON product_product_files (file_id)');
        $this->addSql('COMMENT ON COLUMN product_product_files.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_files.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_files.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_product_files.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_product_image (id INT NOT NULL, product_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_BE8C63F14584665A ON product_product_image (product_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_BE8C63F13DA5256D ON product_product_image (image_id)');
        $this->addSql('COMMENT ON COLUMN product_product_image.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_image.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_image.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_product_image.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_product_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, header TEXT DEFAULT NULL, name TEXT NOT NULL, quality TEXT DEFAULT NULL, other_text1 TEXT DEFAULT NULL, ribbon_custom TEXT DEFAULT NULL, slug VARCHAR(255) NOT NULL, description TEXT NOT NULL, intro_text TEXT DEFAULT NULL, info_shop TEXT DEFAULT NULL, dosage TEXT DEFAULT NULL, tasting TEXT DEFAULT NULL, assemblages JSON DEFAULT NULL, winemaking JSON DEFAULT NULL, select_variant TEXT DEFAULT NULL, show_info_shop_only_on_panel BOOLEAN NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_410730E2989D9B62 ON product_product_translation (slug)');
        $this->addSql('CREATE INDEX IDX_410730E22C2AC5D3 ON product_product_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX product_product_translation_unique_translation ON product_product_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN product_product_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_product_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_tax (id UUID NOT NULL, name VARCHAR(255) NOT NULL, by_default BOOLEAN NOT NULL, in_pro BOOLEAN NOT NULL, out_pro BOOLEAN NOT NULL, in_customer BOOLEAN NOT NULL, out_customer BOOLEAN NOT NULL, value NUMERIC(3, 2) NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN product_tax.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_tax.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_tax.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_type (id UUID NOT NULL, position INT NOT NULL, volume NUMERIC(5, 2) DEFAULT NULL, unity VARCHAR(255) DEFAULT NULL, maximum_quantity_cart INT DEFAULT NULL, multiple_quantity_cart INT DEFAULT 1 NOT NULL, multiple_quantity_depot INT DEFAULT 1 NOT NULL, equivalency_manu NUMERIC(4, 2) NOT NULL, equivalency NUMERIC(4, 2) NOT NULL, equivalency_degressive NUMERIC(4, 2) DEFAULT \'1\' NOT NULL, equivalency_free_shipping NUMERIC(4, 2) NOT NULL, equivalency_default BOOLEAN NOT NULL, equivalency_on_shipping BOOLEAN NOT NULL, equivalency_default_quantity BOOLEAN NOT NULL, equivalency_on_free_shipping BOOLEAN NOT NULL, disabled_shipping_manu BOOLEAN NOT NULL, disabled_shipping_auto BOOLEAN NOT NULL, free_shipping_with_bottle BOOLEAN NOT NULL, min_free_shipping_with_bottle INT DEFAULT NULL, accessory BOOLEAN DEFAULT false NOT NULL, order_witha_minimum_equivalency INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN product_type.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_type.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_type.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_type_shipping_zone (product_type_id UUID NOT NULL, shipping_zone_id UUID NOT NULL, PRIMARY KEY(product_type_id, shipping_zone_id))');
        $this->addSql('CREATE INDEX IDX_B36C644C14959723 ON product_type_shipping_zone (product_type_id)');
        $this->addSql('CREATE INDEX IDX_B36C644C7964396F ON product_type_shipping_zone (shipping_zone_id)');
        $this->addSql('COMMENT ON COLUMN product_type_shipping_zone.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_type_shipping_zone.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_type_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, info TEXT DEFAULT NULL, slug VARCHAR(255) NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_71FCF602989D9B62 ON product_type_translation (slug)');
        $this->addSql('CREATE INDEX IDX_71FCF6022C2AC5D3 ON product_type_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX product_type_translation_unique_translation ON product_type_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN product_type_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_type_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE product_variant (id UUID NOT NULL, product_id UUID DEFAULT NULL, product_type_id UUID DEFAULT NULL, lot INT NOT NULL, position INT DEFAULT NULL, by_default BOOLEAN NOT NULL, un_published BOOLEAN NOT NULL, sold_out BOOLEAN NOT NULL, stock_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, stock INT DEFAULT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_209AA41D4584665A ON product_variant (product_id)');
        $this->addSql('CREATE INDEX IDX_209AA41D14959723 ON product_variant (product_type_id)');
        $this->addSql('COMMENT ON COLUMN product_variant.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant.product_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_variant.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_variant.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_variant_image (id INT NOT NULL, variant_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_9F5A87F03B69A9AF ON product_variant_image (variant_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_9F5A87F03DA5256D ON product_variant_image (image_id)');
        $this->addSql('COMMENT ON COLUMN product_variant_image.variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_image.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_image.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_image.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_variant_option (id UUID NOT NULL, variant_id UUID NOT NULL, position INT DEFAULT NULL, price INT DEFAULT 0 NOT NULL, flat_fee BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_1CB5D94A3B69A9AF ON product_variant_option (variant_id)');
        $this->addSql('COMMENT ON COLUMN product_variant_option.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option.variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_variant_option_image (id INT NOT NULL, option_id UUID DEFAULT NULL, image_id UUID DEFAULT NULL, position INT DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_5AB3385DA7C41D6F ON product_variant_option_image (option_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_5AB3385D3DA5256D ON product_variant_option_image (image_id)');
        $this->addSql('COMMENT ON COLUMN product_variant_option_image.option_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option_image.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option_image.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option_image.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE product_variant_option_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name TEXT NOT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_66B98F262C2AC5D3 ON product_variant_option_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX product_variant_option_translation_unique_translation ON product_variant_option_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN product_variant_option_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN product_variant_option_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE seed_run (id UUID NOT NULL, run_id UUID NOT NULL, status VARCHAR(20) NOT NULL, started_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, finished_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, payload JSON NOT NULL, error TEXT DEFAULT NULL, last_retry_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, attempt INT NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_96A1071A84E3FEC4 ON seed_run (run_id)');
        $this->addSql('COMMENT ON COLUMN seed_run.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.run_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.started_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.finished_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.payload IS \'(DC2Type:json_document)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.last_retry_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN seed_run.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE seed_state (id UUID NOT NULL, seed_name VARCHAR(80) NOT NULL, version INT DEFAULT 0 NOT NULL, run_id UUID NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_979BCBEB84E3FEC4 ON seed_state (run_id)');
        $this->addSql('COMMENT ON COLUMN seed_state.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN seed_state.run_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN seed_state.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN seed_state.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_config_disable_country_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, description VARCHAR(255) DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_95F6C4A82C2AC5D3 ON shop_config_disable_country_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_config_disable_country_translation_unique_translation ON shop_config_disable_country_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_config_disable_country_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_config_disable_country_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_config_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, vacation TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_586E20F2C2AC5D3 ON shop_config_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_config_translation_unique_translation ON shop_config_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_config_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_config_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_delivery_method (id UUID NOT NULL, delivery_category_id UUID DEFAULT NULL, un_published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, package_price INT DEFAULT NULL, bottle_price INT DEFAULT NULL, multiple_variant BOOLEAN DEFAULT false NOT NULL, disabled_equivalence BOOLEAN NOT NULL, enabled_shipping_price BOOLEAN NOT NULL, view_counties BOOLEAN NOT NULL, position INT DEFAULT NULL, qty_at INT DEFAULT NULL, view_product BOOLEAN NOT NULL, depot BOOLEAN NOT NULL, disabled BOOLEAN DEFAULT false NOT NULL, deleted_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_A9BBC7DA2E5B3CA4 ON shop_delivery_method (delivery_category_id)');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method.delivery_category_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method.deleted_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_delivery_method_counties (deliverymethod_id UUID NOT NULL, countie_id UUID NOT NULL, PRIMARY KEY(deliverymethod_id, countie_id))');
        $this->addSql('CREATE INDEX IDX_8A63F2F656299D6B ON shop_delivery_method_counties (deliverymethod_id)');
        $this->addSql('CREATE INDEX IDX_8A63F2F6F4D070C4 ON shop_delivery_method_counties (countie_id)');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_counties.deliverymethod_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_counties.countie_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_delivery_method_group_price (delivery_method_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(delivery_method_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_C4511B475DED75F5 ON shop_delivery_method_group_price (delivery_method_id)');
        $this->addSql('CREATE INDEX IDX_C4511B47CF8B9C7C ON shop_delivery_method_group_price (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_group_price.delivery_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_group_price.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE delivery_method_product_variant (delivery_method_id UUID NOT NULL, product_variant_id UUID NOT NULL, PRIMARY KEY(delivery_method_id, product_variant_id))');
        $this->addSql('CREATE INDEX IDX_42134CFA5DED75F5 ON delivery_method_product_variant (delivery_method_id)');
        $this->addSql('CREATE INDEX IDX_42134CFAA80EF684 ON delivery_method_product_variant (product_variant_id)');
        $this->addSql('COMMENT ON COLUMN delivery_method_product_variant.delivery_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN delivery_method_product_variant.product_variant_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_delivery_method_category (id UUID NOT NULL, position INT NOT NULL, min_view BOOLEAN NOT NULL, disabled_shipping_address BOOLEAN DEFAULT false NOT NULL, disabled BOOLEAN DEFAULT false NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_category.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_delivery_method_category_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name VARCHAR(255) NOT NULL, description TEXT DEFAULT NULL, min_view_text_open VARCHAR(255) DEFAULT NULL, min_view_text_close VARCHAR(255) DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_43F04D132C2AC5D3 ON shop_delivery_method_category_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_delivery_method_category_translation_unique_translation ON shop_delivery_method_category_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_category_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_category_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_delivery_method_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, name VARCHAR(255) NOT NULL, description TEXT DEFAULT NULL, other_text TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_EADC57962C2AC5D3 ON shop_delivery_method_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_delivery_method_translation_unique_translation ON shop_delivery_method_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_delivery_method_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_information_block (id UUID NOT NULL, image_id UUID DEFAULT NULL, action_type VARCHAR(20) DEFAULT \'none\' NOT NULL, button_url TEXT DEFAULT NULL, modal_template VARCHAR(50) DEFAULT \'none\' NOT NULL, display_zone VARCHAR(10) DEFAULT \'top\' NOT NULL, published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, un_published_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, position INT DEFAULT 0, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_5C7B8DEF3DA5256D ON shop_information_block (image_id)');
        $this->addSql('COMMENT ON COLUMN shop_information_block.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_information_block.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_information_block.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_information_block.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_information_block_group_price (information_block_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(information_block_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_D8E2934C6EF8107E ON shop_information_block_group_price (information_block_id)');
        $this->addSql('CREATE INDEX IDX_D8E2934CCF8B9C7C ON shop_information_block_group_price (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shop_information_block_group_price.information_block_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_information_block_group_price.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_information_block_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, title VARCHAR(255) NOT NULL, description TEXT NOT NULL, button_label VARCHAR(255) DEFAULT NULL, modal_title VARCHAR(255) DEFAULT NULL, modal_description TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_F66FDF9D2C2AC5D3 ON shop_information_block_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_information_block_translation_unique_translation ON shop_information_block_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_information_block_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_information_block_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_additional (id UUID NOT NULL, qty_of INT NOT NULL, qty_at INT DEFAULT NULL, date_of INT NOT NULL, date_at INT NOT NULL, price INT NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_shipping_additional_counties (shipping_additional_id UUID NOT NULL, countie_id UUID NOT NULL, PRIMARY KEY(shipping_additional_id, countie_id))');
        $this->addSql('CREATE INDEX IDX_931FD8BCAD05DCE7 ON shop_shipping_additional_counties (shipping_additional_id)');
        $this->addSql('CREATE INDEX IDX_931FD8BCF4D070C4 ON shop_shipping_additional_counties (countie_id)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional_counties.shipping_additional_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional_counties.countie_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_additional_product_price_group (shipping_additional_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(shipping_additional_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_B07ABDC0AD05DCE7 ON shipping_additional_product_price_group (shipping_additional_id)');
        $this->addSql('CREATE INDEX IDX_B07ABDC0CF8B9C7C ON shipping_additional_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shipping_additional_product_price_group.shipping_additional_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_additional_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_additional_manual (id UUID NOT NULL, qty_of INT NOT NULL, qty_at INT DEFAULT NULL, date_of INT NOT NULL, date_at INT NOT NULL, package_price INT DEFAULT NULL, bottle_price INT DEFAULT NULL, ht BOOLEAN NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional_manual.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional_manual.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_additional_manual.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shipping_additional_manual_shipping_zone (shipping_additional_manual_id UUID NOT NULL, shipping_zone_id UUID NOT NULL, PRIMARY KEY(shipping_additional_manual_id, shipping_zone_id))');
        $this->addSql('CREATE INDEX IDX_2BC6D4CF90BE2BDD ON shipping_additional_manual_shipping_zone (shipping_additional_manual_id)');
        $this->addSql('CREATE INDEX IDX_2BC6D4CF7964396F ON shipping_additional_manual_shipping_zone (shipping_zone_id)');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_shipping_zone.shipping_additional_manual_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_shipping_zone.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_additional_manual_product_type (shipping_additional_manual_id UUID NOT NULL, product_type_id UUID NOT NULL, PRIMARY KEY(shipping_additional_manual_id, product_type_id))');
        $this->addSql('CREATE INDEX IDX_4A60C29C90BE2BDD ON shipping_additional_manual_product_type (shipping_additional_manual_id)');
        $this->addSql('CREATE INDEX IDX_4A60C29C14959723 ON shipping_additional_manual_product_type (product_type_id)');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_product_type.shipping_additional_manual_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_product_type.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_additional_manual_product_price_group (shipping_additional_manual_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(shipping_additional_manual_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_853EACFD90BE2BDD ON shipping_additional_manual_product_price_group (shipping_additional_manual_id)');
        $this->addSql('CREATE INDEX IDX_853EACFDCF8B9C7C ON shipping_additional_manual_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_product_price_group.shipping_additional_manual_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_additional_manual_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_auto (id UUID NOT NULL, qty_of INT NOT NULL, qty_at INT DEFAULT NULL, package_price INT DEFAULT NULL, bottle_price INT DEFAULT NULL, county VARCHAR(255) NOT NULL, country VARCHAR(255) NOT NULL, h_m BOOLEAN NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_auto.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_auto_sup (id UUID NOT NULL, postal VARCHAR(255) DEFAULT NULL, city VARCHAR(255) NOT NULL, county VARCHAR(255) NOT NULL, country VARCHAR(255) NOT NULL, verification BOOLEAN NOT NULL, old_name VARCHAR(255) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_auto_sup.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_config (id UUID NOT NULL, file_sup_id UUID DEFAULT NULL, file_id UUID DEFAULT NULL, margin_gazole_auto NUMERIC(5, 4) DEFAULT NULL, margin_auto NUMERIC(5, 4) DEFAULT NULL, margin_client_auto NUMERIC(5, 4) DEFAULT NULL, margin_manu NUMERIC(5, 4) DEFAULT NULL, margin_client_manu NUMERIC(5, 4) DEFAULT NULL, tva_manu NUMERIC(5, 4) DEFAULT NULL, margin_bank NUMERIC(5, 4) DEFAULT NULL, amount_margin_bank INT DEFAULT NULL, qty_equivalency_bottle INT DEFAULT NULL, amount_min_vdmanu INT DEFAULT NULL, qty_min_vdmanu INT DEFAULT NULL, amount_by_bottle_ttc INT DEFAULT NULL, amount_auto_by_bottle_ttc INT DEFAULT NULL, amount_min_vdauto INT DEFAULT NULL, qty_min_vdauto INT DEFAULT NULL, amount_vdauto INT DEFAULT NULL, amount_percent_vdauto NUMERIC(5, 4) DEFAULT NULL, amount_fixed_before_marge_auto INT DEFAULT 0 NOT NULL, amount_fixed_auto INT DEFAULT 0 NOT NULL, amount_fixed_manu INT DEFAULT 0 NOT NULL, high_mountain_amount INT DEFAULT NULL, amount_free_shipping INT DEFAULT NULL, force_equivalency_for_auto BOOLEAN NOT NULL, carrier VARCHAR(255) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_1623EE07476E2B72 ON shop_shipping_config (file_sup_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_1623EE0793CB796C ON shop_shipping_config (file_id)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config.file_sup_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config.file_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_shipping_config_translation (id UUID NOT NULL, translatable_id UUID DEFAULT NULL, shipping_text VARCHAR(255) DEFAULT NULL, shipping_info TEXT DEFAULT NULL, locale VARCHAR(5) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_90BF15972C2AC5D3 ON shop_shipping_config_translation (translatable_id)');
        $this->addSql('CREATE UNIQUE INDEX shop_shipping_config_translation_unique_translation ON shop_shipping_config_translation (translatable_id, locale)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config_translation.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_config_translation.translatable_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_country (id UUID NOT NULL, code VARCHAR(255) NOT NULL, county BOOLEAN NOT NULL, min_qty INT DEFAULT NULL, multiple INT DEFAULT NULL, disabled BOOLEAN DEFAULT false NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_country.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_country_product_price_group (shipping_country_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(shipping_country_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_40FD24F241D46E2E ON shipping_country_product_price_group (shipping_country_id)');
        $this->addSql('CREATE INDEX IDX_40FD24F2CF8B9C7C ON shipping_country_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shipping_country_product_price_group.shipping_country_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_country_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_county (id UUID NOT NULL, zone_id UUID DEFAULT NULL, code VARCHAR(255) NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_9A4B3E5E9F2C3FAB ON shop_shipping_county (zone_id)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_county.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_county.zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_price (id UUID NOT NULL, delivery_method_id UUID DEFAULT NULL, qty_of INT NOT NULL, qty_at INT DEFAULT NULL, package_price INT DEFAULT NULL, bottle_price INT DEFAULT NULL, config_global BOOLEAN DEFAULT false NOT NULL, private_marge_percent NUMERIC(5, 4) DEFAULT NULL, private_marge INT DEFAULT NULL, name_carrier VARCHAR(255) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_B4F6FE655DED75F5 ON shop_shipping_price (delivery_method_id)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_price.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_price.delivery_method_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_price.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_price.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shipping_price_shipping_zone (shipping_price_id UUID NOT NULL, shipping_zone_id UUID NOT NULL, PRIMARY KEY(shipping_price_id, shipping_zone_id))');
        $this->addSql('CREATE INDEX IDX_2DF37FA94AFB8948 ON shipping_price_shipping_zone (shipping_price_id)');
        $this->addSql('CREATE INDEX IDX_2DF37FA97964396F ON shipping_price_shipping_zone (shipping_zone_id)');
        $this->addSql('COMMENT ON COLUMN shipping_price_shipping_zone.shipping_price_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_price_shipping_zone.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_price_product_type (shipping_price_id UUID NOT NULL, product_type_id UUID NOT NULL, PRIMARY KEY(shipping_price_id, product_type_id))');
        $this->addSql('CREATE INDEX IDX_C97EBBD94AFB8948 ON shipping_price_product_type (shipping_price_id)');
        $this->addSql('CREATE INDEX IDX_C97EBBD914959723 ON shipping_price_product_type (product_type_id)');
        $this->addSql('COMMENT ON COLUMN shipping_price_product_type.shipping_price_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_price_product_type.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shipping_price_product_price_group (shipping_price_id UUID NOT NULL, product_price_group_id UUID NOT NULL, PRIMARY KEY(shipping_price_id, product_price_group_id))');
        $this->addSql('CREATE INDEX IDX_9F1C9A1C4AFB8948 ON shipping_price_product_price_group (shipping_price_id)');
        $this->addSql('CREATE INDEX IDX_9F1C9A1CCF8B9C7C ON shipping_price_product_price_group (product_price_group_id)');
        $this->addSql('COMMENT ON COLUMN shipping_price_product_price_group.shipping_price_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shipping_price_product_price_group.product_price_group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_tax (id UUID NOT NULL, by_default BOOLEAN NOT NULL, in_pro BOOLEAN NOT NULL, out_pro BOOLEAN NOT NULL, in_customer BOOLEAN NOT NULL, out_customer BOOLEAN NOT NULL, value NUMERIC(3, 2) NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_tax.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_tax.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_tax.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_shipping_zone (id UUID NOT NULL, name VARCHAR(255) NOT NULL, disabled BOOLEAN DEFAULT false NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN shop_shipping_zone.id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shipping_countries_zones (shipping_zone_id UUID NOT NULL, shipping_country_id UUID NOT NULL, PRIMARY KEY(shipping_zone_id, shipping_country_id))');
        $this->addSql('CREATE INDEX IDX_C5B48F957964396F ON shop_shipping_countries_zones (shipping_zone_id)');
        $this->addSql('CREATE INDEX IDX_C5B48F9541D46E2E ON shop_shipping_countries_zones (shipping_country_id)');
        $this->addSql('COMMENT ON COLUMN shop_shipping_countries_zones.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shipping_countries_zones.shipping_country_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_shop_config (id UUID NOT NULL, image_id UUID DEFAULT NULL, hide_price_default BOOLEAN NOT NULL, enable_award_shop BOOLEAN NOT NULL, max_awards_visible_in_shop INT DEFAULT NULL, enable_countries_for_shop JSON DEFAULT \'[]\', vacation_of TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, vacation_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, disable_shop_for_vacation BOOLEAN NOT NULL, degrissivity_by_item BOOLEAN NOT NULL, invoice BOOLEAN DEFAULT false NOT NULL, invoice_payment_term VARCHAR(64) DEFAULT NULL, invoice_suffix VARCHAR(64) DEFAULT NULL, enable_partner_code_front BOOLEAN DEFAULT true NOT NULL, enable_product_page_front BOOLEAN DEFAULT false NOT NULL, show_partner_code_when_shop_blocked BOOLEAN DEFAULT false NOT NULL, google_tag_manager_id VARCHAR(64) DEFAULT NULL, google_analytics_ids JSON DEFAULT \'[]\', facebook_pixel_ids JSON DEFAULT \'[]\', tracking_head_scripts TEXT DEFAULT NULL, tracking_body_scripts TEXT DEFAULT NULL, tracking_checkout_scripts TEXT DEFAULT NULL, tracking_payment_confirmation_scripts TEXT DEFAULT NULL, tracking_payment_error_scripts TEXT DEFAULT NULL, tracking_payment_canceled_scripts TEXT DEFAULT NULL, tracking_contact_scripts TEXT DEFAULT NULL, tracking_contact_success_scripts TEXT DEFAULT NULL, enable_checkout_event_tracking BOOLEAN DEFAULT false NOT NULL, enable_payment_success_event_tracking BOOLEAN DEFAULT false NOT NULL, enable_payment_error_event_tracking BOOLEAN DEFAULT false NOT NULL, enable_payment_canceled_event_tracking BOOLEAN DEFAULT false NOT NULL, enable_contact_page_event_tracking BOOLEAN DEFAULT false NOT NULL, enable_contact_success_event_tracking BOOLEAN DEFAULT false NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_835FFFEE3DA5256D ON shop_shop_config (image_id)');
        $this->addSql('COMMENT ON COLUMN shop_shop_config.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config.image_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_shop_config_disable_country (id UUID NOT NULL, config_id UUID DEFAULT NULL, country VARCHAR(255) NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_56D435B124DB0683 ON shop_shop_config_disable_country (config_id)');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_disable_country.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_disable_country.config_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_disable_country.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_disable_country.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_shop_config_multiple (id UUID NOT NULL, config_id UUID DEFAULT NULL, qty_of INT NOT NULL, qty_at INT NOT NULL, multiple INT NOT NULL, minimum BOOLEAN NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_B2719BD324DB0683 ON shop_shop_config_multiple (config_id)');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_multiple.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_multiple.config_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_multiple.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN shop_shop_config_multiple.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE shop_config_multiple_shipping_zone (shop_config_multiple_id UUID NOT NULL, shipping_zone_id UUID NOT NULL, PRIMARY KEY(shop_config_multiple_id, shipping_zone_id))');
        $this->addSql('CREATE INDEX IDX_EFD186701F33EB1D ON shop_config_multiple_shipping_zone (shop_config_multiple_id)');
        $this->addSql('CREATE INDEX IDX_EFD186707964396F ON shop_config_multiple_shipping_zone (shipping_zone_id)');
        $this->addSql('COMMENT ON COLUMN shop_config_multiple_shipping_zone.shop_config_multiple_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_config_multiple_shipping_zone.shipping_zone_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE shop_config_multiple_product_type (shop_config_multiple_id UUID NOT NULL, product_type_id UUID NOT NULL, PRIMARY KEY(shop_config_multiple_id, product_type_id))');
        $this->addSql('CREATE INDEX IDX_3C78C5651F33EB1D ON shop_config_multiple_product_type (shop_config_multiple_id)');
        $this->addSql('CREATE INDEX IDX_3C78C56514959723 ON shop_config_multiple_product_type (product_type_id)');
        $this->addSql('COMMENT ON COLUMN shop_config_multiple_product_type.shop_config_multiple_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN shop_config_multiple_product_type.product_type_id IS \'(DC2Type:uuid)\'');
        $this->addSql('CREATE TABLE socialnetwork_socialnetwork (id UUID NOT NULL, network VARCHAR(255) NOT NULL, configuration JSON DEFAULT NULL, token VARCHAR(255) DEFAULT NULL, token_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, data JSON NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetwork.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetwork.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetwork.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE socialnetwork_socialnetworkNew (id UUID NOT NULL, connect_id VARCHAR(255) NOT NULL, username VARCHAR(255) DEFAULT NULL, network VARCHAR(255) NOT NULL, data JSON NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetworkNew.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetworkNew.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN socialnetwork_socialnetworkNew.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE user_delivery_address (id UUID NOT NULL, phone VARCHAR(12) DEFAULT NULL, lastname VARCHAR(255) DEFAULT NULL, firstname VARCHAR(255) DEFAULT NULL, company VARCHAR(255) DEFAULT NULL, siret VARCHAR(14) DEFAULT NULL, vat_id VARCHAR(16) DEFAULT NULL, street VARCHAR(255) DEFAULT NULL, postal VARCHAR(8) DEFAULT NULL, city VARCHAR(255) DEFAULT NULL, country VARCHAR(2) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN user_delivery_address.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_delivery_address.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN user_delivery_address.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE user_invoice_address (id UUID NOT NULL, email TEXT DEFAULT NULL, phone VARCHAR(12) DEFAULT NULL, lastname VARCHAR(255) DEFAULT NULL, firstname VARCHAR(255) DEFAULT NULL, company VARCHAR(255) DEFAULT NULL, siret VARCHAR(14) DEFAULT NULL, vat_id VARCHAR(16) DEFAULT NULL, street VARCHAR(255) DEFAULT NULL, postal VARCHAR(8) DEFAULT NULL, city VARCHAR(255) DEFAULT NULL, country VARCHAR(2) DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('COMMENT ON COLUMN user_invoice_address.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_invoice_address.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN user_invoice_address.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE user_user (id UUID NOT NULL, invoice_address_id UUID DEFAULT NULL, delivery_address_id UUID DEFAULT NULL, group_id UUID DEFAULT NULL, roles JSON NOT NULL, email VARCHAR(60) NOT NULL, password VARCHAR(255) NOT NULL, marketing_opt_in BOOLEAN DEFAULT false NOT NULL, is_verified BOOLEAN DEFAULT true NOT NULL, email_verification_token VARCHAR(128) DEFAULT NULL, email_verification_requested_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, email_verification_expires_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, reset_password_token VARCHAR(128) DEFAULT NULL, reset_password_requested_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, reset_password_expires_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, last_link_requested_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, updated_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_F7129A80E7927C74 ON user_user (email)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_F7129A80C4995C67 ON user_user (email_verification_token)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_F7129A80452C9EC5 ON user_user (reset_password_token)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_F7129A80C6BDFEB ON user_user (invoice_address_id)');
        $this->addSql('CREATE UNIQUE INDEX UNIQ_F7129A80EBF23851 ON user_user (delivery_address_id)');
        $this->addSql('CREATE INDEX IDX_F7129A80FE54D947 ON user_user (group_id)');
        $this->addSql('COMMENT ON COLUMN user_user.id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_user.invoice_address_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_user.delivery_address_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_user.group_id IS \'(DC2Type:uuid)\'');
        $this->addSql('COMMENT ON COLUMN user_user.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN user_user.updated_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('CREATE TABLE messenger_messages (id BIGSERIAL NOT NULL, body TEXT NOT NULL, headers TEXT NOT NULL, queue_name VARCHAR(190) NOT NULL, created_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, available_at TIMESTAMP(0) WITHOUT TIME ZONE NOT NULL, delivered_at TIMESTAMP(0) WITHOUT TIME ZONE DEFAULT NULL, PRIMARY KEY(id))');
        $this->addSql('CREATE INDEX IDX_75EA56E0FB7336F0E3BD61CE16BA31DBBF396750 ON messenger_messages (queue_name, available_at, delivered_at, id)');
        $this->addSql('COMMENT ON COLUMN messenger_messages.created_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN messenger_messages.available_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('COMMENT ON COLUMN messenger_messages.delivered_at IS \'(DC2Type:datetime_immutable)\'');
        $this->addSql('ALTER TABLE award_award ADD CONSTRAINT FK_857D6ED13DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE award_award_translation ADD CONSTRAINT FK_1A78042C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES award_award (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart ADD CONSTRAINT FK_E446888E5DED75F5 FOREIGN KEY (delivery_method_id) REFERENCES shop_delivery_method (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart ADD CONSTRAINT FK_E446888EC6BDFEB FOREIGN KEY (invoice_address_id) REFERENCES cart_invoice_address (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart ADD CONSTRAINT FK_E446888EEBF23851 FOREIGN KEY (delivery_address_id) REFERENCES cart_delivery_address (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart ADD CONSTRAINT FK_E446888EA76ED395 FOREIGN KEY (user_id) REFERENCES user_user (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart ADD CONSTRAINT FK_E446888E2989F1FD FOREIGN KEY (invoice_id) REFERENCES cart_invoice (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart_checkout ADD CONSTRAINT FK_5BF344B5AA1164F FOREIGN KEY (payment_method_id) REFERENCES cart_payment_method (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart_checkout ADD CONSTRAINT FK_5BF344BE10F05B8 FOREIGN KEY (cart_cart_id) REFERENCES cart_cart (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart_item ADD CONSTRAINT FK_2A0002B8E10F05B8 FOREIGN KEY (cart_cart_id) REFERENCES cart_cart (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_cart_item ADD CONSTRAINT FK_2A0002B8A80EF684 FOREIGN KEY (product_variant_id) REFERENCES product_variant (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_payment_method ADD CONSTRAINT FK_D15FF5FF3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_payment_method_translation ADD CONSTRAINT FK_6F3AC5652C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES cart_payment_method (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_promo ADD CONSTRAINT FK_EFF9F7F3B93BFD91 FOREIGN KEY (offered_variant_id) REFERENCES product_variant (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_promo ADD CONSTRAINT FK_EFF9F7F3ADF66B1A FOREIGN KEY (assigned_user_id) REFERENCES user_user (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_product_price_group ADD CONSTRAINT FK_B306621DD0C07AFF FOREIGN KEY (promo_id) REFERENCES cart_promo (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_product_price_group ADD CONSTRAINT FK_B306621DCF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_shipping_zone ADD CONSTRAINT FK_B21CD505D0C07AFF FOREIGN KEY (promo_id) REFERENCES cart_promo (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_shipping_zone ADD CONSTRAINT FK_B21CD5057964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_product ADD CONSTRAINT FK_DB3EBC9FD0C07AFF FOREIGN KEY (promo_id) REFERENCES cart_promo (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE promo_product ADD CONSTRAINT FK_DB3EBC9F4584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_promo_incompatible_auto ADD CONSTRAINT FK_7ADFD619BDF67BDA FOREIGN KEY (promo_source_id) REFERENCES cart_promo (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE cart_promo_incompatible_auto ADD CONSTRAINT FK_7ADFD6193D446CDD FOREIGN KEY (promo_target_id) REFERENCES cart_promo (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE contact_contact ADD CONSTRAINT FK_D64DC7B993CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE contact_contact ADD CONSTRAINT FK_D64DC7B93DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE contact_label ADD CONSTRAINT FK_238D40E73DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE contact_label_translation ADD CONSTRAINT FK_A81638CE2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES contact_label (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE depot_category ADD CONSTRAINT FK_81579E5F3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE depot_category_translation ADD CONSTRAINT FK_5BC61832C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES depot_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE depot_depot ADD CONSTRAINT FK_2165D81B1B6CCFFF FOREIGN KEY (depot_category_id) REFERENCES depot_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE depot_depot_translation ADD CONSTRAINT FK_8086EE492C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES depot_depot (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE event_event ADD CONSTRAINT FK_7AB5BB8B93CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE event_event_image ADD CONSTRAINT FK_2FAF66F371F7E88B FOREIGN KEY (event_id) REFERENCES event_event (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE event_event_image ADD CONSTRAINT FK_2FAF66F33DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE event_event_translation ADD CONSTRAINT FK_8A79CC8E2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES event_event (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE library_library ADD CONSTRAINT FK_DB41208C3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE library_library_translation ADD CONSTRAINT FK_EEAFE95D2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES library_library (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_category_translation ADD CONSTRAINT FK_C8B8CAF92C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES news_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news ADD CONSTRAINT FK_C80E6FDB3B732BAD FOREIGN KEY (news_category_id) REFERENCES news_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news ADD CONSTRAINT FK_C80E6FDB93CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news ADD CONSTRAINT FK_C80E6FDB29C1004E FOREIGN KEY (video_id) REFERENCES media_media (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news_image ADD CONSTRAINT FK_53FD5478B5A459A0 FOREIGN KEY (news_id) REFERENCES news_news (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news_image ADD CONSTRAINT FK_53FD54783DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE news_news_translation ADD CONSTRAINT FK_1900956E2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES news_news (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE payment_payment ADD CONSTRAINT FK_74618AE75AA1164F FOREIGN KEY (payment_method_id) REFERENCES cart_payment_method (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE popup_popup ADD CONSTRAINT FK_7CC1198F3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE popup_popup ADD CONSTRAINT FK_7CC1198F29C1004E FOREIGN KEY (video_id) REFERENCES media_media (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE popup_popup_translation ADD CONSTRAINT FK_ACD6A8102C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES popup_popup (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_category_translation ADD CONSTRAINT FK_1DAAB4872C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES product_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product_type ADD CONSTRAINT FK_E75F62BF54BEF7E FOREIGN KEY (product_degressive_id) REFERENCES product_degressive (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product_type ADD CONSTRAINT FK_E75F62BF14959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product_price_group ADD CONSTRAINT FK_FE07709D54BEF7E FOREIGN KEY (product_degressive_id) REFERENCES product_degressive (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product_price_group ADD CONSTRAINT FK_FE07709DCF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product ADD CONSTRAINT FK_CC09F11054BEF7E FOREIGN KEY (product_degressive_id) REFERENCES product_degressive (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_degressive_product ADD CONSTRAINT FK_CC09F1104584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_option ADD CONSTRAINT FK_38FA411414959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_option_translation ADD CONSTRAINT FK_608B99A72C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES product_option (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_price ADD CONSTRAINT FK_6B945985FE54D947 FOREIGN KEY (group_id) REFERENCES product_price_group (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_price ADD CONSTRAINT FK_6B9459853B69A9AF FOREIGN KEY (variant_id) REFERENCES product_variant (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_price_code ADD CONSTRAINT FK_99209D09FE54D947 FOREIGN KEY (group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product ADD CONSTRAINT FK_2931F1DBE6903FD FOREIGN KEY (product_category_id) REFERENCES product_category (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product ADD CONSTRAINT FK_2931F1DEB17A08 FOREIGN KEY (second_image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product ADD CONSTRAINT FK_2931F1DE6DA28AA FOREIGN KEY (background_image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product ADD CONSTRAINT FK_2931F1D93CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product ADD CONSTRAINT FK_2931F1D3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_award ADD CONSTRAINT FK_2B0755BB4584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_award ADD CONSTRAINT FK_2B0755BB3D5282CF FOREIGN KEY (award_id) REFERENCES award_award (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_price_group ADD CONSTRAINT FK_B36739284584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_price_group ADD CONSTRAINT FK_B3673928CF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_files ADD CONSTRAINT FK_7D8427F74584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_files ADD CONSTRAINT FK_7D8427F793CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_image ADD CONSTRAINT FK_BE8C63F14584665A FOREIGN KEY (product_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_image ADD CONSTRAINT FK_BE8C63F13DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_product_translation ADD CONSTRAINT FK_410730E22C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES product_product (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_type_shipping_zone ADD CONSTRAINT FK_B36C644C14959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_type_shipping_zone ADD CONSTRAINT FK_B36C644C7964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_type_translation ADD CONSTRAINT FK_71FCF6022C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant ADD CONSTRAINT FK_209AA41D4584665A FOREIGN KEY (product_id) REFERENCES product_product (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant ADD CONSTRAINT FK_209AA41D14959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_image ADD CONSTRAINT FK_9F5A87F03B69A9AF FOREIGN KEY (variant_id) REFERENCES product_variant (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_image ADD CONSTRAINT FK_9F5A87F03DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_option ADD CONSTRAINT FK_1CB5D94A3B69A9AF FOREIGN KEY (variant_id) REFERENCES product_variant (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_option_image ADD CONSTRAINT FK_5AB3385DA7C41D6F FOREIGN KEY (option_id) REFERENCES product_variant_option (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_option_image ADD CONSTRAINT FK_5AB3385D3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE product_variant_option_translation ADD CONSTRAINT FK_66B98F262C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES product_variant_option (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_disable_country_translation ADD CONSTRAINT FK_95F6C4A82C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_shop_config_disable_country (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_translation ADD CONSTRAINT FK_586E20F2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_shop_config (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method ADD CONSTRAINT FK_A9BBC7DA2E5B3CA4 FOREIGN KEY (delivery_category_id) REFERENCES shop_delivery_method_category (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_counties ADD CONSTRAINT FK_8A63F2F656299D6B FOREIGN KEY (deliverymethod_id) REFERENCES shop_delivery_method (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_counties ADD CONSTRAINT FK_8A63F2F6F4D070C4 FOREIGN KEY (countie_id) REFERENCES shop_shipping_county (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_group_price ADD CONSTRAINT FK_C4511B475DED75F5 FOREIGN KEY (delivery_method_id) REFERENCES shop_delivery_method (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_group_price ADD CONSTRAINT FK_C4511B47CF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE delivery_method_product_variant ADD CONSTRAINT FK_42134CFA5DED75F5 FOREIGN KEY (delivery_method_id) REFERENCES shop_delivery_method (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE delivery_method_product_variant ADD CONSTRAINT FK_42134CFAA80EF684 FOREIGN KEY (product_variant_id) REFERENCES product_variant (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_category_translation ADD CONSTRAINT FK_43F04D132C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_delivery_method_category (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_delivery_method_translation ADD CONSTRAINT FK_EADC57962C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_delivery_method (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_information_block ADD CONSTRAINT FK_5C7B8DEF3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_information_block_group_price ADD CONSTRAINT FK_D8E2934C6EF8107E FOREIGN KEY (information_block_id) REFERENCES shop_information_block (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_information_block_group_price ADD CONSTRAINT FK_D8E2934CCF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_information_block_translation ADD CONSTRAINT FK_F66FDF9D2C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_information_block (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_additional_counties ADD CONSTRAINT FK_931FD8BCAD05DCE7 FOREIGN KEY (shipping_additional_id) REFERENCES shop_shipping_additional (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_additional_counties ADD CONSTRAINT FK_931FD8BCF4D070C4 FOREIGN KEY (countie_id) REFERENCES shop_shipping_county (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_product_price_group ADD CONSTRAINT FK_B07ABDC0AD05DCE7 FOREIGN KEY (shipping_additional_id) REFERENCES shop_shipping_additional (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_product_price_group ADD CONSTRAINT FK_B07ABDC0CF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_shipping_zone ADD CONSTRAINT FK_2BC6D4CF90BE2BDD FOREIGN KEY (shipping_additional_manual_id) REFERENCES shop_shipping_additional_manual (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_shipping_zone ADD CONSTRAINT FK_2BC6D4CF7964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_type ADD CONSTRAINT FK_4A60C29C90BE2BDD FOREIGN KEY (shipping_additional_manual_id) REFERENCES shop_shipping_additional_manual (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_type ADD CONSTRAINT FK_4A60C29C14959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_price_group ADD CONSTRAINT FK_853EACFD90BE2BDD FOREIGN KEY (shipping_additional_manual_id) REFERENCES shop_shipping_additional_manual (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_price_group ADD CONSTRAINT FK_853EACFDCF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_config ADD CONSTRAINT FK_1623EE07476E2B72 FOREIGN KEY (file_sup_id) REFERENCES media_media (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_config ADD CONSTRAINT FK_1623EE0793CB796C FOREIGN KEY (file_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_config_translation ADD CONSTRAINT FK_90BF15972C2AC5D3 FOREIGN KEY (translatable_id) REFERENCES shop_shipping_config (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_country_product_price_group ADD CONSTRAINT FK_40FD24F241D46E2E FOREIGN KEY (shipping_country_id) REFERENCES shop_shipping_country (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_country_product_price_group ADD CONSTRAINT FK_40FD24F2CF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_county ADD CONSTRAINT FK_9A4B3E5E9F2C3FAB FOREIGN KEY (zone_id) REFERENCES shop_shipping_zone (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_price ADD CONSTRAINT FK_B4F6FE655DED75F5 FOREIGN KEY (delivery_method_id) REFERENCES shop_delivery_method (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_shipping_zone ADD CONSTRAINT FK_2DF37FA94AFB8948 FOREIGN KEY (shipping_price_id) REFERENCES shop_shipping_price (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_shipping_zone ADD CONSTRAINT FK_2DF37FA97964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_product_type ADD CONSTRAINT FK_C97EBBD94AFB8948 FOREIGN KEY (shipping_price_id) REFERENCES shop_shipping_price (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_product_type ADD CONSTRAINT FK_C97EBBD914959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_product_price_group ADD CONSTRAINT FK_9F1C9A1C4AFB8948 FOREIGN KEY (shipping_price_id) REFERENCES shop_shipping_price (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shipping_price_product_price_group ADD CONSTRAINT FK_9F1C9A1CCF8B9C7C FOREIGN KEY (product_price_group_id) REFERENCES product_price_group (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_countries_zones ADD CONSTRAINT FK_C5B48F957964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shipping_countries_zones ADD CONSTRAINT FK_C5B48F9541D46E2E FOREIGN KEY (shipping_country_id) REFERENCES shop_shipping_country (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shop_config ADD CONSTRAINT FK_835FFFEE3DA5256D FOREIGN KEY (image_id) REFERENCES media_media (id) ON DELETE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shop_config_disable_country ADD CONSTRAINT FK_56D435B124DB0683 FOREIGN KEY (config_id) REFERENCES shop_shop_config (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_shop_config_multiple ADD CONSTRAINT FK_B2719BD324DB0683 FOREIGN KEY (config_id) REFERENCES shop_shop_config (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_multiple_shipping_zone ADD CONSTRAINT FK_EFD186701F33EB1D FOREIGN KEY (shop_config_multiple_id) REFERENCES shop_shop_config_multiple (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_multiple_shipping_zone ADD CONSTRAINT FK_EFD186707964396F FOREIGN KEY (shipping_zone_id) REFERENCES shop_shipping_zone (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_multiple_product_type ADD CONSTRAINT FK_3C78C5651F33EB1D FOREIGN KEY (shop_config_multiple_id) REFERENCES shop_shop_config_multiple (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE shop_config_multiple_product_type ADD CONSTRAINT FK_3C78C56514959723 FOREIGN KEY (product_type_id) REFERENCES product_type (id) ON DELETE CASCADE NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE user_user ADD CONSTRAINT FK_F7129A80C6BDFEB FOREIGN KEY (invoice_address_id) REFERENCES user_invoice_address (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE user_user ADD CONSTRAINT FK_F7129A80EBF23851 FOREIGN KEY (delivery_address_id) REFERENCES user_delivery_address (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
        $this->addSql('ALTER TABLE user_user ADD CONSTRAINT FK_F7129A80FE54D947 FOREIGN KEY (group_id) REFERENCES product_price_group (id) NOT DEFERRABLE INITIALLY IMMEDIATE');
    }

    public function down(Schema $schema): void
    {
        // this down() migration is auto-generated, please modify it to your needs
        $this->addSql('CREATE SCHEMA public');
        $this->addSql('DROP SEQUENCE event_event_image_id_seq CASCADE');
        $this->addSql('DROP SEQUENCE news_news_image_id_seq CASCADE');
        $this->addSql('DROP SEQUENCE product_product_files_id_seq CASCADE');
        $this->addSql('DROP SEQUENCE product_product_image_id_seq CASCADE');
        $this->addSql('DROP SEQUENCE product_variant_image_id_seq CASCADE');
        $this->addSql('DROP SEQUENCE product_variant_option_image_id_seq CASCADE');
        $this->addSql('ALTER TABLE award_award DROP CONSTRAINT FK_857D6ED13DA5256D');
        $this->addSql('ALTER TABLE award_award_translation DROP CONSTRAINT FK_1A78042C2AC5D3');
        $this->addSql('ALTER TABLE cart_cart DROP CONSTRAINT FK_E446888E5DED75F5');
        $this->addSql('ALTER TABLE cart_cart DROP CONSTRAINT FK_E446888EC6BDFEB');
        $this->addSql('ALTER TABLE cart_cart DROP CONSTRAINT FK_E446888EEBF23851');
        $this->addSql('ALTER TABLE cart_cart DROP CONSTRAINT FK_E446888EA76ED395');
        $this->addSql('ALTER TABLE cart_cart DROP CONSTRAINT FK_E446888E2989F1FD');
        $this->addSql('ALTER TABLE cart_cart_checkout DROP CONSTRAINT FK_5BF344B5AA1164F');
        $this->addSql('ALTER TABLE cart_cart_checkout DROP CONSTRAINT FK_5BF344BE10F05B8');
        $this->addSql('ALTER TABLE cart_cart_item DROP CONSTRAINT FK_2A0002B8E10F05B8');
        $this->addSql('ALTER TABLE cart_cart_item DROP CONSTRAINT FK_2A0002B8A80EF684');
        $this->addSql('ALTER TABLE cart_payment_method DROP CONSTRAINT FK_D15FF5FF3DA5256D');
        $this->addSql('ALTER TABLE cart_payment_method_translation DROP CONSTRAINT FK_6F3AC5652C2AC5D3');
        $this->addSql('ALTER TABLE cart_promo DROP CONSTRAINT FK_EFF9F7F3B93BFD91');
        $this->addSql('ALTER TABLE cart_promo DROP CONSTRAINT FK_EFF9F7F3ADF66B1A');
        $this->addSql('ALTER TABLE promo_product_price_group DROP CONSTRAINT FK_B306621DD0C07AFF');
        $this->addSql('ALTER TABLE promo_product_price_group DROP CONSTRAINT FK_B306621DCF8B9C7C');
        $this->addSql('ALTER TABLE promo_shipping_zone DROP CONSTRAINT FK_B21CD505D0C07AFF');
        $this->addSql('ALTER TABLE promo_shipping_zone DROP CONSTRAINT FK_B21CD5057964396F');
        $this->addSql('ALTER TABLE promo_product DROP CONSTRAINT FK_DB3EBC9FD0C07AFF');
        $this->addSql('ALTER TABLE promo_product DROP CONSTRAINT FK_DB3EBC9F4584665A');
        $this->addSql('ALTER TABLE cart_promo_incompatible_auto DROP CONSTRAINT FK_7ADFD619BDF67BDA');
        $this->addSql('ALTER TABLE cart_promo_incompatible_auto DROP CONSTRAINT FK_7ADFD6193D446CDD');
        $this->addSql('ALTER TABLE contact_contact DROP CONSTRAINT FK_D64DC7B993CB796C');
        $this->addSql('ALTER TABLE contact_contact DROP CONSTRAINT FK_D64DC7B93DA5256D');
        $this->addSql('ALTER TABLE contact_label DROP CONSTRAINT FK_238D40E73DA5256D');
        $this->addSql('ALTER TABLE contact_label_translation DROP CONSTRAINT FK_A81638CE2C2AC5D3');
        $this->addSql('ALTER TABLE depot_category DROP CONSTRAINT FK_81579E5F3DA5256D');
        $this->addSql('ALTER TABLE depot_category_translation DROP CONSTRAINT FK_5BC61832C2AC5D3');
        $this->addSql('ALTER TABLE depot_depot DROP CONSTRAINT FK_2165D81B1B6CCFFF');
        $this->addSql('ALTER TABLE depot_depot_translation DROP CONSTRAINT FK_8086EE492C2AC5D3');
        $this->addSql('ALTER TABLE event_event DROP CONSTRAINT FK_7AB5BB8B93CB796C');
        $this->addSql('ALTER TABLE event_event_image DROP CONSTRAINT FK_2FAF66F371F7E88B');
        $this->addSql('ALTER TABLE event_event_image DROP CONSTRAINT FK_2FAF66F33DA5256D');
        $this->addSql('ALTER TABLE event_event_translation DROP CONSTRAINT FK_8A79CC8E2C2AC5D3');
        $this->addSql('ALTER TABLE library_library DROP CONSTRAINT FK_DB41208C3DA5256D');
        $this->addSql('ALTER TABLE library_library_translation DROP CONSTRAINT FK_EEAFE95D2C2AC5D3');
        $this->addSql('ALTER TABLE news_category_translation DROP CONSTRAINT FK_C8B8CAF92C2AC5D3');
        $this->addSql('ALTER TABLE news_news DROP CONSTRAINT FK_C80E6FDB3B732BAD');
        $this->addSql('ALTER TABLE news_news DROP CONSTRAINT FK_C80E6FDB93CB796C');
        $this->addSql('ALTER TABLE news_news DROP CONSTRAINT FK_C80E6FDB29C1004E');
        $this->addSql('ALTER TABLE news_news_image DROP CONSTRAINT FK_53FD5478B5A459A0');
        $this->addSql('ALTER TABLE news_news_image DROP CONSTRAINT FK_53FD54783DA5256D');
        $this->addSql('ALTER TABLE news_news_translation DROP CONSTRAINT FK_1900956E2C2AC5D3');
        $this->addSql('ALTER TABLE payment_payment DROP CONSTRAINT FK_74618AE75AA1164F');
        $this->addSql('ALTER TABLE popup_popup DROP CONSTRAINT FK_7CC1198F3DA5256D');
        $this->addSql('ALTER TABLE popup_popup DROP CONSTRAINT FK_7CC1198F29C1004E');
        $this->addSql('ALTER TABLE popup_popup_translation DROP CONSTRAINT FK_ACD6A8102C2AC5D3');
        $this->addSql('ALTER TABLE product_category_translation DROP CONSTRAINT FK_1DAAB4872C2AC5D3');
        $this->addSql('ALTER TABLE product_degressive_product_type DROP CONSTRAINT FK_E75F62BF54BEF7E');
        $this->addSql('ALTER TABLE product_degressive_product_type DROP CONSTRAINT FK_E75F62BF14959723');
        $this->addSql('ALTER TABLE product_degressive_product_price_group DROP CONSTRAINT FK_FE07709D54BEF7E');
        $this->addSql('ALTER TABLE product_degressive_product_price_group DROP CONSTRAINT FK_FE07709DCF8B9C7C');
        $this->addSql('ALTER TABLE product_degressive_product DROP CONSTRAINT FK_CC09F11054BEF7E');
        $this->addSql('ALTER TABLE product_degressive_product DROP CONSTRAINT FK_CC09F1104584665A');
        $this->addSql('ALTER TABLE product_option DROP CONSTRAINT FK_38FA411414959723');
        $this->addSql('ALTER TABLE product_option_translation DROP CONSTRAINT FK_608B99A72C2AC5D3');
        $this->addSql('ALTER TABLE product_price DROP CONSTRAINT FK_6B945985FE54D947');
        $this->addSql('ALTER TABLE product_price DROP CONSTRAINT FK_6B9459853B69A9AF');
        $this->addSql('ALTER TABLE product_price_code DROP CONSTRAINT FK_99209D09FE54D947');
        $this->addSql('ALTER TABLE product_product DROP CONSTRAINT FK_2931F1DBE6903FD');
        $this->addSql('ALTER TABLE product_product DROP CONSTRAINT FK_2931F1DEB17A08');
        $this->addSql('ALTER TABLE product_product DROP CONSTRAINT FK_2931F1DE6DA28AA');
        $this->addSql('ALTER TABLE product_product DROP CONSTRAINT FK_2931F1D93CB796C');
        $this->addSql('ALTER TABLE product_product DROP CONSTRAINT FK_2931F1D3DA5256D');
        $this->addSql('ALTER TABLE product_award DROP CONSTRAINT FK_2B0755BB4584665A');
        $this->addSql('ALTER TABLE product_award DROP CONSTRAINT FK_2B0755BB3D5282CF');
        $this->addSql('ALTER TABLE product_product_price_group DROP CONSTRAINT FK_B36739284584665A');
        $this->addSql('ALTER TABLE product_product_price_group DROP CONSTRAINT FK_B3673928CF8B9C7C');
        $this->addSql('ALTER TABLE product_product_files DROP CONSTRAINT FK_7D8427F74584665A');
        $this->addSql('ALTER TABLE product_product_files DROP CONSTRAINT FK_7D8427F793CB796C');
        $this->addSql('ALTER TABLE product_product_image DROP CONSTRAINT FK_BE8C63F14584665A');
        $this->addSql('ALTER TABLE product_product_image DROP CONSTRAINT FK_BE8C63F13DA5256D');
        $this->addSql('ALTER TABLE product_product_translation DROP CONSTRAINT FK_410730E22C2AC5D3');
        $this->addSql('ALTER TABLE product_type_shipping_zone DROP CONSTRAINT FK_B36C644C14959723');
        $this->addSql('ALTER TABLE product_type_shipping_zone DROP CONSTRAINT FK_B36C644C7964396F');
        $this->addSql('ALTER TABLE product_type_translation DROP CONSTRAINT FK_71FCF6022C2AC5D3');
        $this->addSql('ALTER TABLE product_variant DROP CONSTRAINT FK_209AA41D4584665A');
        $this->addSql('ALTER TABLE product_variant DROP CONSTRAINT FK_209AA41D14959723');
        $this->addSql('ALTER TABLE product_variant_image DROP CONSTRAINT FK_9F5A87F03B69A9AF');
        $this->addSql('ALTER TABLE product_variant_image DROP CONSTRAINT FK_9F5A87F03DA5256D');
        $this->addSql('ALTER TABLE product_variant_option DROP CONSTRAINT FK_1CB5D94A3B69A9AF');
        $this->addSql('ALTER TABLE product_variant_option_image DROP CONSTRAINT FK_5AB3385DA7C41D6F');
        $this->addSql('ALTER TABLE product_variant_option_image DROP CONSTRAINT FK_5AB3385D3DA5256D');
        $this->addSql('ALTER TABLE product_variant_option_translation DROP CONSTRAINT FK_66B98F262C2AC5D3');
        $this->addSql('ALTER TABLE shop_config_disable_country_translation DROP CONSTRAINT FK_95F6C4A82C2AC5D3');
        $this->addSql('ALTER TABLE shop_config_translation DROP CONSTRAINT FK_586E20F2C2AC5D3');
        $this->addSql('ALTER TABLE shop_delivery_method DROP CONSTRAINT FK_A9BBC7DA2E5B3CA4');
        $this->addSql('ALTER TABLE shop_delivery_method_counties DROP CONSTRAINT FK_8A63F2F656299D6B');
        $this->addSql('ALTER TABLE shop_delivery_method_counties DROP CONSTRAINT FK_8A63F2F6F4D070C4');
        $this->addSql('ALTER TABLE shop_delivery_method_group_price DROP CONSTRAINT FK_C4511B475DED75F5');
        $this->addSql('ALTER TABLE shop_delivery_method_group_price DROP CONSTRAINT FK_C4511B47CF8B9C7C');
        $this->addSql('ALTER TABLE delivery_method_product_variant DROP CONSTRAINT FK_42134CFA5DED75F5');
        $this->addSql('ALTER TABLE delivery_method_product_variant DROP CONSTRAINT FK_42134CFAA80EF684');
        $this->addSql('ALTER TABLE shop_delivery_method_category_translation DROP CONSTRAINT FK_43F04D132C2AC5D3');
        $this->addSql('ALTER TABLE shop_delivery_method_translation DROP CONSTRAINT FK_EADC57962C2AC5D3');
        $this->addSql('ALTER TABLE shop_information_block DROP CONSTRAINT FK_5C7B8DEF3DA5256D');
        $this->addSql('ALTER TABLE shop_information_block_group_price DROP CONSTRAINT FK_D8E2934C6EF8107E');
        $this->addSql('ALTER TABLE shop_information_block_group_price DROP CONSTRAINT FK_D8E2934CCF8B9C7C');
        $this->addSql('ALTER TABLE shop_information_block_translation DROP CONSTRAINT FK_F66FDF9D2C2AC5D3');
        $this->addSql('ALTER TABLE shop_shipping_additional_counties DROP CONSTRAINT FK_931FD8BCAD05DCE7');
        $this->addSql('ALTER TABLE shop_shipping_additional_counties DROP CONSTRAINT FK_931FD8BCF4D070C4');
        $this->addSql('ALTER TABLE shipping_additional_product_price_group DROP CONSTRAINT FK_B07ABDC0AD05DCE7');
        $this->addSql('ALTER TABLE shipping_additional_product_price_group DROP CONSTRAINT FK_B07ABDC0CF8B9C7C');
        $this->addSql('ALTER TABLE shipping_additional_manual_shipping_zone DROP CONSTRAINT FK_2BC6D4CF90BE2BDD');
        $this->addSql('ALTER TABLE shipping_additional_manual_shipping_zone DROP CONSTRAINT FK_2BC6D4CF7964396F');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_type DROP CONSTRAINT FK_4A60C29C90BE2BDD');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_type DROP CONSTRAINT FK_4A60C29C14959723');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_price_group DROP CONSTRAINT FK_853EACFD90BE2BDD');
        $this->addSql('ALTER TABLE shipping_additional_manual_product_price_group DROP CONSTRAINT FK_853EACFDCF8B9C7C');
        $this->addSql('ALTER TABLE shop_shipping_config DROP CONSTRAINT FK_1623EE07476E2B72');
        $this->addSql('ALTER TABLE shop_shipping_config DROP CONSTRAINT FK_1623EE0793CB796C');
        $this->addSql('ALTER TABLE shop_shipping_config_translation DROP CONSTRAINT FK_90BF15972C2AC5D3');
        $this->addSql('ALTER TABLE shipping_country_product_price_group DROP CONSTRAINT FK_40FD24F241D46E2E');
        $this->addSql('ALTER TABLE shipping_country_product_price_group DROP CONSTRAINT FK_40FD24F2CF8B9C7C');
        $this->addSql('ALTER TABLE shop_shipping_county DROP CONSTRAINT FK_9A4B3E5E9F2C3FAB');
        $this->addSql('ALTER TABLE shop_shipping_price DROP CONSTRAINT FK_B4F6FE655DED75F5');
        $this->addSql('ALTER TABLE shipping_price_shipping_zone DROP CONSTRAINT FK_2DF37FA94AFB8948');
        $this->addSql('ALTER TABLE shipping_price_shipping_zone DROP CONSTRAINT FK_2DF37FA97964396F');
        $this->addSql('ALTER TABLE shipping_price_product_type DROP CONSTRAINT FK_C97EBBD94AFB8948');
        $this->addSql('ALTER TABLE shipping_price_product_type DROP CONSTRAINT FK_C97EBBD914959723');
        $this->addSql('ALTER TABLE shipping_price_product_price_group DROP CONSTRAINT FK_9F1C9A1C4AFB8948');
        $this->addSql('ALTER TABLE shipping_price_product_price_group DROP CONSTRAINT FK_9F1C9A1CCF8B9C7C');
        $this->addSql('ALTER TABLE shop_shipping_countries_zones DROP CONSTRAINT FK_C5B48F957964396F');
        $this->addSql('ALTER TABLE shop_shipping_countries_zones DROP CONSTRAINT FK_C5B48F9541D46E2E');
        $this->addSql('ALTER TABLE shop_shop_config DROP CONSTRAINT FK_835FFFEE3DA5256D');
        $this->addSql('ALTER TABLE shop_shop_config_disable_country DROP CONSTRAINT FK_56D435B124DB0683');
        $this->addSql('ALTER TABLE shop_shop_config_multiple DROP CONSTRAINT FK_B2719BD324DB0683');
        $this->addSql('ALTER TABLE shop_config_multiple_shipping_zone DROP CONSTRAINT FK_EFD186701F33EB1D');
        $this->addSql('ALTER TABLE shop_config_multiple_shipping_zone DROP CONSTRAINT FK_EFD186707964396F');
        $this->addSql('ALTER TABLE shop_config_multiple_product_type DROP CONSTRAINT FK_3C78C5651F33EB1D');
        $this->addSql('ALTER TABLE shop_config_multiple_product_type DROP CONSTRAINT FK_3C78C56514959723');
        $this->addSql('ALTER TABLE user_user DROP CONSTRAINT FK_F7129A80C6BDFEB');
        $this->addSql('ALTER TABLE user_user DROP CONSTRAINT FK_F7129A80EBF23851');
        $this->addSql('ALTER TABLE user_user DROP CONSTRAINT FK_F7129A80FE54D947');
        $this->addSql('DROP TABLE award_award');
        $this->addSql('DROP TABLE award_award_translation');
        $this->addSql('DROP TABLE cart_cart');
        $this->addSql('DROP TABLE cart_cart_checkout');
        $this->addSql('DROP TABLE cart_cart_item');
        $this->addSql('DROP TABLE cart_delivery_address');
        $this->addSql('DROP TABLE cart_invoice');
        $this->addSql('DROP TABLE cart_invoice_address');
        $this->addSql('DROP TABLE cart_payment_method');
        $this->addSql('DROP TABLE cart_payment_method_translation');
        $this->addSql('DROP TABLE cart_promo');
        $this->addSql('DROP TABLE promo_product_price_group');
        $this->addSql('DROP TABLE promo_shipping_zone');
        $this->addSql('DROP TABLE promo_product');
        $this->addSql('DROP TABLE cart_promo_incompatible_auto');
        $this->addSql('DROP TABLE contact_contact');
        $this->addSql('DROP TABLE contact_label');
        $this->addSql('DROP TABLE contact_label_translation');
        $this->addSql('DROP TABLE depot_category');
        $this->addSql('DROP TABLE depot_category_translation');
        $this->addSql('DROP TABLE depot_depot');
        $this->addSql('DROP TABLE depot_depot_translation');
        $this->addSql('DROP TABLE event_event');
        $this->addSql('DROP TABLE event_event_image');
        $this->addSql('DROP TABLE event_event_translation');
        $this->addSql('DROP TABLE library_library');
        $this->addSql('DROP TABLE library_library_translation');
        $this->addSql('DROP TABLE locale_locale');
        $this->addSql('DROP TABLE media_media');
        $this->addSql('DROP TABLE news_category');
        $this->addSql('DROP TABLE news_category_translation');
        $this->addSql('DROP TABLE news_news');
        $this->addSql('DROP TABLE news_news_image');
        $this->addSql('DROP TABLE news_news_translation');
        $this->addSql('DROP TABLE payment_payment');
        $this->addSql('DROP TABLE popup_popup');
        $this->addSql('DROP TABLE popup_popup_translation');
        $this->addSql('DROP TABLE product_category');
        $this->addSql('DROP TABLE product_category_translation');
        $this->addSql('DROP TABLE product_degressive');
        $this->addSql('DROP TABLE product_degressive_product_type');
        $this->addSql('DROP TABLE product_degressive_product_price_group');
        $this->addSql('DROP TABLE product_degressive_product');
        $this->addSql('DROP TABLE product_option');
        $this->addSql('DROP TABLE product_option_translation');
        $this->addSql('DROP TABLE product_price');
        $this->addSql('DROP TABLE product_price_code');
        $this->addSql('DROP TABLE product_price_group');
        $this->addSql('DROP TABLE product_product');
        $this->addSql('DROP TABLE product_award');
        $this->addSql('DROP TABLE product_product_price_group');
        $this->addSql('DROP TABLE product_product_files');
        $this->addSql('DROP TABLE product_product_image');
        $this->addSql('DROP TABLE product_product_translation');
        $this->addSql('DROP TABLE product_tax');
        $this->addSql('DROP TABLE product_type');
        $this->addSql('DROP TABLE product_type_shipping_zone');
        $this->addSql('DROP TABLE product_type_translation');
        $this->addSql('DROP TABLE product_variant');
        $this->addSql('DROP TABLE product_variant_image');
        $this->addSql('DROP TABLE product_variant_option');
        $this->addSql('DROP TABLE product_variant_option_image');
        $this->addSql('DROP TABLE product_variant_option_translation');
        $this->addSql('DROP TABLE seed_run');
        $this->addSql('DROP TABLE seed_state');
        $this->addSql('DROP TABLE shop_config_disable_country_translation');
        $this->addSql('DROP TABLE shop_config_translation');
        $this->addSql('DROP TABLE shop_delivery_method');
        $this->addSql('DROP TABLE shop_delivery_method_counties');
        $this->addSql('DROP TABLE shop_delivery_method_group_price');
        $this->addSql('DROP TABLE delivery_method_product_variant');
        $this->addSql('DROP TABLE shop_delivery_method_category');
        $this->addSql('DROP TABLE shop_delivery_method_category_translation');
        $this->addSql('DROP TABLE shop_delivery_method_translation');
        $this->addSql('DROP TABLE shop_information_block');
        $this->addSql('DROP TABLE shop_information_block_group_price');
        $this->addSql('DROP TABLE shop_information_block_translation');
        $this->addSql('DROP TABLE shop_shipping_additional');
        $this->addSql('DROP TABLE shop_shipping_additional_counties');
        $this->addSql('DROP TABLE shipping_additional_product_price_group');
        $this->addSql('DROP TABLE shop_shipping_additional_manual');
        $this->addSql('DROP TABLE shipping_additional_manual_shipping_zone');
        $this->addSql('DROP TABLE shipping_additional_manual_product_type');
        $this->addSql('DROP TABLE shipping_additional_manual_product_price_group');
        $this->addSql('DROP TABLE shop_shipping_auto');
        $this->addSql('DROP TABLE shop_shipping_auto_sup');
        $this->addSql('DROP TABLE shop_shipping_config');
        $this->addSql('DROP TABLE shop_shipping_config_translation');
        $this->addSql('DROP TABLE shop_shipping_country');
        $this->addSql('DROP TABLE shipping_country_product_price_group');
        $this->addSql('DROP TABLE shop_shipping_county');
        $this->addSql('DROP TABLE shop_shipping_price');
        $this->addSql('DROP TABLE shipping_price_shipping_zone');
        $this->addSql('DROP TABLE shipping_price_product_type');
        $this->addSql('DROP TABLE shipping_price_product_price_group');
        $this->addSql('DROP TABLE shop_shipping_tax');
        $this->addSql('DROP TABLE shop_shipping_zone');
        $this->addSql('DROP TABLE shop_shipping_countries_zones');
        $this->addSql('DROP TABLE shop_shop_config');
        $this->addSql('DROP TABLE shop_shop_config_disable_country');
        $this->addSql('DROP TABLE shop_shop_config_multiple');
        $this->addSql('DROP TABLE shop_config_multiple_shipping_zone');
        $this->addSql('DROP TABLE shop_config_multiple_product_type');
        $this->addSql('DROP TABLE socialnetwork_socialnetwork');
        $this->addSql('DROP TABLE socialnetwork_socialnetworkNew');
        $this->addSql('DROP TABLE user_delivery_address');
        $this->addSql('DROP TABLE user_invoice_address');
        $this->addSql('DROP TABLE user_user');
        $this->addSql('DROP TABLE messenger_messages');
    }
}
